pub struct UnprocessedOptions {
ts: TokenStream,
pub beta_enabled: Option<Enabled>,
}Expand description
All the template options, as a tokenstream, but sanity-checked
These have been syntax checked, but not semantically checked. The purpose of the syntax check is to get syntax errors early, when a template is defined - rather than when it’s applied.
This also helps with cross-crate compatibility.
Fields
ts: TokenStreambeta_enabled: Option<Enabled>Implementations
Sourceimpl UnprocessedOptions
impl UnprocessedOptions
pub fn parse(input: ParseStream<'_>, opcontext: OpContext) -> Result<Self>